% Cleanup
clear all
close all

% Load nominal parameters
load('parameters.mat');

% Detuning factors and unbalancing
xc = [0.97, 1.00, 1.03];
xu = 0.98; %sqrt(L_1/L_2)*V_2nom/V_1nom;

k = 0.4;
R1 = R_1;
R2 = R_2;

% Choose iterations and range
N = 1000;
inc = 0.8*omega_0/N;
omega_min = 0.7*omega_0;
freq = omega_min;

% Initialize vectors and cells
nomPowerVec = zeros(1,length(xc));
data.powerVec = zeros(N,length(xc));
omegaVec = zeros(N,1);

legends = cell(1,length(xc));
for j = 1:length(xc)
    legends(j) = {strcat('$x_c$=', num2str(xc(j)))};
    nomPowerVec(j) = getPower(k, V_2nom, R1, R2, C_2, L_1, L_2, xu, xc(j), omega_0);
    for i = 1:N
        data.powerVec(i,j) = getPower(k,V_2nom, R1, R2, C_2, L_1, L_2, xu, xc(j), freq);
        omegaVec(i) = freq;
        freq = freq + inc;
    end
    freq = omega_min;
end

legends{1,2} = '$x_c$=1.00';

% Remove invalid parts of plot
start1 = 195; start2 = 179; start3 = 164;
end1 = 776; end2 = 751; end3 = 727;

% Plot frequency characteristics
figure
hold on  
grid on
plot(omegaVec(start1:end1)/omega_0, abs(real(data.powerVec(start1:end1 ,1))/nomPowerVec(1)), 'r', 'LineWidth', 1.3);
plot(omegaVec(start2:end2)/omega_0, abs(real(data.powerVec(start2:end2 ,2))/nomPowerVec(2)), 'b', 'LineWidth', 1.3);
plot(omegaVec(start3:end3)/omega_0, abs(real(data.powerVec(start3:end3 ,3))/nomPowerVec(3)), 'color', [0,0.4,0], 'LineWidth', 1.3);
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized power $(P_{out}/P_0)$', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.75 1.4])
ylim([0 5])