% Cleanup
clear all
close all

% Load nominal parameters
load('parameters.mat');
Vdc = V_dcout;

% Detuning factors and unbalancing
xc = [0.97, 1.00, 1.03];
xu = 0.98; %sqrt(L_1/L_2)*V_2nom/V_1nom;

k = 0.4;
R1 = R_1;
R2 = R_2;

% Choose iterations and range
N = 500;
inc = 0.55*omega_0/N;
omega_min = 0.8*omega_0;
freq = omega_min;

% Initialize vectors and cells
data.argZVec = zeros(N,length(xc));
omegaVec = zeros(N,1);

legends = cell(1,length(xc));
for j = 1:length(xc)
    legends(j) = {strcat('$x_c$=', num2str(xc(j)))};
    for i = 1:N
        SteadyState = getSteadyState(freq, R1, R2, xu, xc(j), k, Vdc);
        data.argZVec(i,j) = angle(V_1nom/(SteadyState(1)+1i*SteadyState(2)));
        omegaVec(i) = freq;
        freq = freq + inc;
    end
    freq = omega_min;
end

legends{1,2} = '$x_c$=1.00';

% Plot phase characteristics
figure
grid on
hold on
plot(omegaVec/omega_0, data.argZVec(:,1)*180/(2*pi), 'r', 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,2)*180/(2*pi), 'b', 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,3)*180/(2*pi), 'color', [0,0.4,0], 'LineWidth', 1.3);
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('$\angle Z_{send}$ [deg]', 'interpreter', 'latex', 'Fontsize', 14)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlim([0.8 1.4])
ylim([-10 10])