% Cleanup
clear all
close all

% Load nominal parameters
load('parameters.mat');

% Unbalancing factors and detuning
xu = [0.94, 0.98, 1.02];
xc = 1.00;

k = 0.4;
R1 = R_1;
R2 = R_2;

% Choose iterations and range
N = 1000;
inc = 0.8*omega_0/N;
omega_min = 0.7*omega_0;
freq = omega_min;

% Initalize vectors and cells
nomPowerVec = zeros(1, length(xu));
data.powerVec = zeros(N,length(xu));
omegaVec = zeros(N,1);

legends = cell(1,length(xu));
for j = 1:length(xu)
    legends(j) = {strcat('$x_u$=', num2str(xu(j)))};
    nomPowerVec(j) = getPower(k, V_2nom, R1, R2, C_2, L_1, L_2, xu(j), xc, omega_0);
    for i = 1:N
        data.powerVec(i,j) = getPower(k, V_2nom, R1, R2, C_2, L_1, L_2, xu(j), xc, freq);
        omegaVec(i) = freq;
        freq = freq + inc;
    end
    freq = omega_min;
end

%legends{1,1} = '$x_u$=0.90';

% Remove invalid parts of plot
%start1 = 166; 
start2 = 173; start3 = 179; start4 = 185; %start5 = 191;
%end1 = 803; 
end2 = 775; end3 = 750; end4 = 729; %end5 = 710;

% Plot frequency characteristics
figure
grid on
hold on  
%plot(omegaVec(start1:end1)/omega_0, abs(real(data.powerVec(start1:end1,1))/nomPowerVec(1)), 'r', 'LineWidth', 1.3);
plot(omegaVec(start2:end2)/omega_0, abs(real(data.powerVec(start2:end2,1))/nomPowerVec(1)),'r','LineWidth', 1.3);
plot(omegaVec(start3:end3)/omega_0, abs(real(data.powerVec(start3:end3,2))/nomPowerVec(2)), 'b', 'LineWidth', 1.3);
plot(omegaVec(start4:end4)/omega_0, abs(real(data.powerVec(start4:end4,3))/nomPowerVec(3)), 'color', [0,0.4,0], 'LineWidth', 1.3);
%plot(omegaVec(start5:end5)/omega_0, abs(real(data.powerVec(start5:end5,5))/nomPowerVec(5)), 'k', 'LineWidth', 1.3);
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized power $(P_{out}/P_0)$', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.75 1.6])
hold off

