% Clenaup
clear all
close all

% Load nominal parameters
load('parameters.mat');

% Unbalancing factors and detuning
xu = [0.94, 0.98, 1.02];
xc = 1.00;

k = 0.4;
R1 = R_1;
R2 = R_2;

% Choose iterations and range
N = 500;
inc = 0.55*omega_0/N;
omega_min = 0.8*omega_0;
freq = omega_min;

% Initalize vectors and cells
data.argZVec = zeros(N,length(xu));
omegaVec = zeros(N,1);

legends = cell(1,length(xu));
for j = 1:length(xu)
    legends(j) = {strcat('$x_u$=', num2str(xu(j)))};
    for i = 1:N
        SteadyState = getSteadyState(freq, R1, R2, xu(j), xc, k);
        data.argZVec(i,j) = angle(V_1nom/(SteadyState(1) +1i*SteadyState(2)));
        omegaVec(i) = freq;
        freq = freq + inc;
    end
    freq = omega_min;
end

%legends{1,1} = '$x_u$=0.90';

% Plot phase characteristics
figure
grid on
hold on
plot(omegaVec/omega_0, data.argZVec(:,1)*180/(2*pi), 'r', 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,2)*180/(2*pi), 'b', 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,3)*180/(2*pi), 'color', [0,0.4,0], 'LineWidth', 1.3);
%plot(omegaVec/omega_0, data.argZVec(:,4)*180/(2*pi), 'c', 'LineWidth', 1.3);
%plot(omegaVec/omega_0, data.argZVec(:,5)*180/(2*pi), 'k', 'LineWidth', 1.3);
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('$\angle Z_{send}$ [deg]', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.8 1.6])
ylim([-15 15])