% Cleanup
close all
clear all

% Load nominal parameters
load('parameters.mat');
Vdc = V_dcout;

% Coupling factors
ks = [0.2, 0.4, 0.6];

% Apply appropriaate detuning and unbalance
xc = 1.03;
xu = 0.98; %sqrt(L_1/L_2)*V_2nom/V_1nom;

% Assign resistances
R1 = R_1;
R2 = R_2;

% Get nominal values
Pnom = getPower(k_nom, V_2nom, R1, R2, C_2, L_1, L_2, xu, xc, omega_0);
I1nom = Pnom/V_1nom;
I2nom = Pnom/V_2nom;

% Choose iterations and range
N = 500;
inc = 0.8*omega_0/N;
omega_min = 0.7*omega_0;
freq = omega_min;

% Initialize vectors and cells
data.argZVec = zeros(N,length(ks));
data.currentVec = zeros(N,length(ks));
data.currentVec2 = zeros(N,length(ks));
data.powerVec = zeros(N,length(ks));
powerRef = zeros(N,1);
omegaVec = zeros(N,1);

legends = cell(1,length(ks));
for j = 1:length(ks)
    legends(j) = {strcat('$k$=', num2str(ks(j)/k_nom), '$.0k_{nom}$')};
    for i = 1:N
        SteadyState = getSteadyState(freq, R1, R2, xu, xc, ks(j), Vdc);
        data.argZVec(i,j) = angle(V_1nom/(SteadyState(1)+1i*SteadyState(2)));
        data.currentVec(i,j) = sqrt(SteadyState(1)^2 + SteadyState(2)^2);
        data.currentVec2(i,j) = sqrt(SteadyState(3)^2 + SteadyState(4)^2);
        data.powerVec(i,j) = getPower(ks(j), V_2nom, R1, R2, C_2, L_1, L_2, xu, xc, freq);
        powerRef(i) = 1;
        omegaVec(i) = freq;
        freq = freq + inc;
    end
    freq = omega_min;
end
legends(1) = {'$k$=$k_{nom}$'};

% Plot phase caracteristics
figure
hold on
plot(omegaVec/omega_0, data.argZVec(:,1)*180/(2*pi), 'b', 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,2)*180/(2*pi), 'color', [0,0.4,0], 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,3)*180/(2*pi), 'r', 'LineWidth', 1.3);
scatter([0.8018 0.8664 1], [2.80 3.16 4.18], [], [1 0 0; 0 0.4 0; 0 0 1], 'LineWidth', 1.3)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('$\angle Z_{send}$ [deg]', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.75 1.1])
ylim([-20 20])
grid on

% Plot frequency characteristics of sending side current
figure
start1 = 125; start2 = 82; start3 = 48;
hold on  
plot(omegaVec(start1:end)/omega_0, abs(real(data.currentVec(start1:end,1))/I1nom), 'b', 'LineWidth', 1.3);
plot(omegaVec(start2:end)/omega_0, abs(real(data.currentVec(start2:end,2))/I1nom), 'color', [0,0.4,0], 'LineWidth', 1.3);
plot(omegaVec(start3:end)/omega_0, abs(real(data.currentVec(start3:end,3))/I1nom), 'r', 'LineWidth', 1.3);
scatter([0.8018 0.8664 1], [0.8 0.8 0.8], [], [1 0 0; 0 0.4 0; 0 0 1], 'LineWidth', 1.3)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized current $(I_1/I_{1,0})$', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.75 1.1])
grid on

% Plot frequency characteristics of receiving side current
figure
start1 = 125; start2 = 82; start3 = 48;
hold on  
plot(omegaVec(start1:end)/omega_0, abs(real(data.currentVec2(start1:end,1))/I2nom), 'b', 'LineWidth', 1.3);
plot(omegaVec(start2:end)/omega_0, abs(real(data.currentVec2(start2:end,2))/I2nom), 'color', [0,0.4,0], 'LineWidth', 1.3);
plot(omegaVec(start3:end)/omega_0, abs(real(data.currentVec2(start3:end,3))/I2nom), 'r', 'LineWidth', 1.3);
scatter([0.8018 0.8664 1], [1 1 1], [], [1 0 0; 0 0.4 0; 0 0 1], 'LineWidth', 1.3)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized current $(I_2/I_{2,0})$', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.75 1.1])
grid on

% Plot frequency characteristics of power
figure
legends(4) = {'$P_{ref}$'};
start1 = 125; start2 = 83; start3 = 49;
hold on  
plot(omegaVec(start1:end)/omega_0, abs(real(data.powerVec(start1:end,1))/Pnom), 'b', 'LineWidth', 1.3);
plot(omegaVec(start2:end)/omega_0, abs(real(data.powerVec(start2:end,2))/Pnom), 'color', [0,0.4,0], 'LineWidth', 1.3);
plot(omegaVec(start3:end)/omega_0, abs(real(data.powerVec(start3:end,3))/Pnom), 'r', 'LineWidth', 1.3);
plot(omegaVec/omega_0, powerRef, '--k', 'LineWidth', 1.3)
scatter([0.8018 0.8664 1], [1 1 1], [], [1 0 0; 0 0.4 0; 0 0 1], 'LineWidth', 1.3)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized power $(P_{out}/P_0)$', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.75 1.1])
grid on