% Cleanup
%close all
clear all

% Load nominal parameters
load('parameters.mat');
Vdc = V_dcout;

% Coupling factors
ks = [0.2, 0.4, 0.6];

% Apply appropriaate detuning and unbalance
xc = 0.97;
xu = 0.95; %sqrt(L_1/L_2)*V_2nom/V_1nom;

% Assign resistances
R1 = R_1;
R2 = R_2;

% Get nominal values
Pnom = getPower(k_nom, V_2nom, R1, R2, C_2, L_1, L_2, xu, xc, omega_0);
I1nom = Pnom/V_1nom;
I2nom = Pnom/V_2nom;

% Choose iterations and range
N = 500;
inc = 0.8*omega_0/N;
omega_min = 0.9*omega_0;
freq = omega_min;

% Initialize vectors and cells
data.argZVec = zeros(N,length(ks));
data.currentVec = zeros(N,length(ks));
data.currentVec2 = zeros(N,length(ks));
data.powerVec = zeros(N,length(ks));
powerRef = zeros(N,1);
omegaVec = zeros(N,1);

legends = cell(1,length(ks));
for j = 1:length(ks)
    legends(j) = {strcat('$k$=', num2str(ks(j)/k_nom), '$.0k_{nom}$')};
    for i = 1:N
        SteadyState = getSteadyState(freq, R1, R2, xu, xc, ks(j), Vdc);
        data.argZVec(i,j) = angle(V_1nom/(SteadyState(1)+1i*SteadyState(2)));
        data.currentVec(i,j) = sqrt(SteadyState(1)^2 + SteadyState(2)^2);
        data.currentVec2(i,j) = sqrt(SteadyState(3)^2 + SteadyState(4)^2);
        data.powerVec(i,j) = getPower(ks(j), V_2nom, R1, R2, C_2, L_1, L_2, xu, xc, freq);
        powerRef(i) = 1;
        omegaVec(i) = freq;
        freq = freq + inc;
    end
    freq = omega_min;
end
legends(1) = {'$k=k_{nom}$'};

% Plot phase caracteristics
figure
hold on
plot(omegaVec/omega_0, data.argZVec(:,1)*180/(2*pi), 'b', 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,2)*180/(2*pi), 'color', [0,0.4,0], 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,3)*180/(2*pi), 'r', 'LineWidth', 1.3);
scatter([1.548 1.255 1], [-4.215 -4.18 -4.305], [], [1 0 0; 0 0.4 0; 0 0 1], 'LineWidth', 1.3)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('$\angle Z_{send}$ [deg]', 'interpreter', 'latex', 'Fontsize', 14)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlim([0.93 1.7])
ylim([-20 20])
grid on

% Plot frequency characteristics of sending side current
figure
end1 = 153; end2 = 273; end3 = 484;
hold on  
plot(omegaVec(1:end1)/omega_0, abs(real(data.currentVec(1:end1,1))/I1nom), 'b', 'LineWidth', 1.3);
plot(omegaVec(1:end2)/omega_0, abs(real(data.currentVec(1:end2,2))/I1nom), 'color', [0,0.4,0], 'LineWidth', 1.3);
plot(omegaVec(1:end3)/omega_0, abs(real(data.currentVec(1:end3,3))/I1nom), 'r', 'LineWidth', 1.3);
scatter([1.548 1.255 1], [0.776 0.776 0.776], [], [1 0 0; 0 0.4 0; 0 0 1], 'LineWidth', 1.3)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized current $(I_1/I_{1,0})$', 'interpreter', 'latex', 'Fontsize', 14)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlim([0.93 1.7])
grid on

% Plot frequency characteristics of receiving side current
figure
end1 = 153; end2 = 273; end3 = 484;
hold on  
plot(omegaVec(1:end1)/omega_0, abs(real(data.currentVec2(1:end1,1))/I2nom), 'b', 'LineWidth', 1.3);
plot(omegaVec(1:end2)/omega_0, abs(real(data.currentVec2(1:end2,2))/I2nom), 'color', [0,0.4,0], 'LineWidth', 1.3);
plot(omegaVec(1:end3)/omega_0, abs(real(data.currentVec2(1:end3,3))/I2nom), 'r', 'LineWidth', 1.3);
scatter([1.548 1.255 1], [1 1 1], [], [1 0 0; 0 0.4 0; 0 0 1], 'LineWidth', 1.3)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized current $(I_2/I_{2,0})$', 'interpreter', 'latex', 'Fontsize', 14)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlim([0.93 1.7])
grid on

figure
legends(4) = {'$P_{ref}$'};
end1 = 153; end2 = 273; end3 = 484;
hold on  
plot(omegaVec(1:end1)/omega_0, abs(real(data.powerVec(1:end1,1))/Pnom), 'b', 'LineWidth', 1.3);
plot(omegaVec(1:end2)/omega_0, abs(real(data.powerVec(1:end2,2))/Pnom), 'color', [0,0.4,0], 'LineWidth', 1.3);
plot(omegaVec(1:end3)/omega_0, abs(real(data.powerVec(1:end3,3))/Pnom), 'r', 'LineWidth', 1.3);
plot(omegaVec/omega_0, powerRef, '--k', 'LineWidth', 1.3)
scatter([1.548 1.255 1], [1 1 1], [], [1 0 0; 0 0.4 0; 0 0 1], 'LineWidth', 1.3)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized power $(P_{out}/P_0)$', 'interpreter', 'latex', 'Fontsize', 14)
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlim([0.93 1.7])
grid on