% Cleanup
clear all
%close all

% Load nominal parameters
load('parameters.mat');
Vdc = V_dcout;

% Unbalancing factors and detuning
xu = [0.96, 0.98, 1.00];
xc = 1.00;

k = 0.4;
R1 = R_1;
R2 = R_2;

% Choose iterations and range
N = 1000;
inc = 0.8*omega_0/N;
omega_min = 0.7*omega_0;
freq = omega_min;

% Initalize vectors and cells
nomPowerVec = zeros(1, length(xu));
data.powerVec = zeros(N,4);
omegaVec = zeros(N,1);
data.argZVec = zeros(N,length(xu));

legends = cell(1,length(xu));
for j = 1:length(xu)
    legends(j) = {strcat('$x_u$=', num2str(xu(j)))};
    nomPowerVec(j) = getPower(k, V_2nom, R1, R2, C_2, L_1, L_2, xu(j), xc, omega_0);
    for i = 1:N
        data.powerVec(i,j) = getPower(k, V_2nom, R1, R2, C_2, L_1, L_2, xu(j), xc, freq);
        SteadyState = getSteadyState(freq, R1, R2, xu(j), xc, k, Vdc);
        data.argZVec(i,j) = angle(V_1nom/(SteadyState(1) +1i*SteadyState(2)));
        omegaVec(i) = freq;
        freq = freq + inc;
    end
    freq = omega_min;
end
%%
xu = 1;
for i = 1:N
    data.powerVec(i,4) = getPower(k, V_2nom, 0, 0, C_2, L_1, L_2, xu, xc, freq);   
    SteadyState = getSteadyState(freq, 0, 0, xu, xc, k, Vdc);
    data.argZVec(i,4) = angle(V_1nom/(SteadyState(1) +1i*SteadyState(2)));
    omegaVec(i) = freq;
    freq = freq + inc;
end
freq = omega_min;
Pnom = getPower(k, V_2nom, 0, 0, C_2, L_1, L_2, xu, xc, omega_0);
legends{1,3} = '$x_u$=1.00';
legends{1,4} = '$x_u$=1.00 (L)';

% Remove invalid parts of plot
start1 = 176; 
start2 = 179; 
start3 = 182; 
start4 = 185; %start5 = 191;
end1 = 763; 
end2 = 750; 
end3 = 740; 
end4 = 735; %end5 = 710;

%% Plot frequency characteristics
figure
grid on
hold on  
plot(omegaVec(start1:end1)/omega_0, abs(real(data.powerVec(start1:end1,1))/nomPowerVec(1)), 'r', 'LineWidth', 1.3);
plot(omegaVec(start2:end2)/omega_0, abs(real(data.powerVec(start2:end2,2))/nomPowerVec(2)), 'color', [0,0.4,0.0], 'LineWidth', 1.3);
plot(omegaVec(start3:end3)/omega_0, abs(real(data.powerVec(start3:end3,3))/nomPowerVec(3)), 'b', 'LineWidth', 1.3);
plot(omegaVec(start4:end4)/omega_0, abs(real(data.powerVec(start4:end4,4))/Pnom), 'k', 'LineWidth', 1.3);
%plot(omegaVec(start5:end5)/omega_0, abs(real(data.powerVec(start5:end5,5))/nomPowerVec(5)), 'k', 'LineWidth', 1.3);
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized power $(P_{out}/P_0)$', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.8 1.55])
ylim([0 4])
%%
limL = sqrt(1/(1+k/xu));
limU = sqrt(1/(1-k/xu));
% x = [limL limL];
% y = [-10 10];
figure
grid on
hold on
plot(omegaVec/omega_0, data.argZVec(:,1)*180/(2*pi), 'r', 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,2)*180/(2*pi), 'color', [0,0.4,0.0], 'LineWidth', 1.3);
plot(omegaVec/omega_0, data.argZVec(:,3)*180/(2*pi), 'b', 'LineWidth', 1.3);
plot(omegaVec(184:739)/omega_0, data.argZVec(184:739,4)*180/(2*pi), 'k', 'LineWidth', 1.3);
line([limL limL],[-10 10],'Color','k','LineStyle','--', 'LineWidth', 1.3)
line([limU limU],[-10 10],'Color','k','LineStyle','--', 'LineWidth', 1.3)
%line([limL limL], [0 4], 'k', 'LineStyle', '--');
%line([limU limU], [0 4], 'k', 'LineStyle', '--');
%plot(omegaVec/omega_0, data.argZVec(:,5)*180/(2*pi), 'k', 'LineWidth', 1.3);
legend(legends, 'interpreter', 'latex', 'Fontsize', 16)
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('$\angle Z_{send}$ [deg]', 'interpreter', 'latex', 'Fontsize', 14)
xlim([0.8 1.55])
ylim([-10 10])