%% Power with varying omega
close all
%clear all
load('parameters.mat');

Vdc = V_dcout;
ks= [0.2, 0.4, 0.6];
xc = 1.03;
xu = 0.98; %sqrt(L_1/L_2)*V_2nom/V_1nom;
R1 = R_1;
R2 = R_2;
Pnom = getPower(k_nom, V_2nom, R1, R2, C_2, L_1, L_2, xu, xc, omega_0);
Pref = Pnom;
legends = cell(1,length(ks));
s = tf('s');

% Gains
K1 = -0.65057; 

% Integral time
Ti = 1/2846; 

% Filter constant
Tf = 1/5340.707511;

% Controller
hr1 = K1*(1 + Ti*s)/(Ti*s);

% Filter
hf = 1/(1+Tf*s);

for i = 1:length(ks)
    k = ks(i);
    k
    legends(i) = {strcat('$k$=', num2str(k/k_nom), '$.0k\_{nom}$')};
    omega = getOmega_constP_subres(k, V_2nom, R_1, R_2, C_2, L_1, L_2, xu, xc, Pref, omega_0);
    [A, B, ~, SteadyState] = getStateSpace(omega, R_1, R_2, xu, xc, k, Vdc);
    C = [sqrt(L_1/L_2)*V_2nom/xu 0 0 0 0 0 0 0;0 0 4/pi*V_dcout*SteadyState(3)/sqrt((SteadyState(3)^2 + SteadyState(4)^2)) ...
    4/pi*V_dcout*SteadyState(4)/sqrt(SteadyState(3)^2 + SteadyState(4)^2) 0 0 0 0];
    sysVec(:,:,i) = ss(A, B, C, []);
    tfomega_sen(:,:,i) = tf(sysVec(1,3,i));
    tfpiomega_sen(:,:,i) = hr1*tfomega_sen(:,:,i)*hf;
    tfomega_rec(:,:,i) = tf(sysVec(2,3,i));
    tfpiomega_rec(:,:,i) = hr1*tfomega_rec(:,:,i)*hf;
end

%%
legends{1,1} = '$k$=$k\_{nom}$';

[num1, den1] = tfdata(tfomega_sen(:,:,1)*hf, 'v');
[num2, den2] = tfdata(tfomega_sen(:,:,2)*hf, 'v');
[num3, den3] = tfdata(tfomega_sen(:,:,3)*hf, 'v');

[num4, den4] = tfdata(tfomega_rec(:,:,1)*hf, 'v');
[num5, den5] = tfdata(tfomega_rec(:,:,2)*hf, 'v');
[num6, den6] = tfdata(tfomega_rec(:,:,3)*hf, 'v');

%%

% Frequency response of sending side plant
figure
hold on
bode(tfomega_sen(:,:,1),'b')
bode(tfomega_sen(:,:,2), 'g')
bode(tfomega_sen(:,:,3), 'r')
legend(legends, 'interpreter', 'latex', 'Fontsize', 14)
title('', 'interpreter', 'latex')
xlim([1e2 1e7])
grid on

% Frequency response with feedback on sending side
figure
hold on
bode(tfpiomega_sen(:,:,1),'b')
bode(tfpiomega_sen(:,:,2), 'g')
bode(tfpiomega_sen(:,:,3), 'r')
legend(legends, 'interpreter', 'latex', 'Fontsize', 14)
title('', 'interpreter', 'latex')
xlim([1e2 1e7])
grid on

% Frequency response of receiving side plant
figure
hold on
bode(tfomega_rec(:,:,1),'b')
bode(tfomega_rec(:,:,2), 'g')
bode(tfomega_rec(:,:,3), 'r')
legend(legends, 'interpreter', 'latex', 'Fontsize', 14)
title('', 'interpreter', 'latex')
xlim([1e2 1e7])
grid on

% Frequency response with feedback on receiving side
figure
hold on
bode(tfpiomega_rec(:,:,1),'b')
bode(tfpiomega_rec(:,:,2), 'g')
bode(tfpiomega_rec(:,:,3), 'r')
legend(legends, 'interpreter', 'latex', 'Fontsize', 14)
title('', 'interpreter', 'latex')
xlim([1e2 1e7])
grid on

%% Pidtune
opt = pidtuneOptions('PhaseMargin',67.5,'DesignFocus', 'balanced');
for i = 1:length(ks)
    Controller(:,:,i) = pidtune(tfomega_sen(:,:,i)*hf, 'PI', opt);
end
