function [A, B] = getSSFromMaple_expanded()    
    %% Symbolic variables and constants
    V_10 = sym('V_10', 'positive');
    V_dcout = sym('V_dcout', 'positive');
    k_nom = sym('k_nom','positive');
    R_1 = sym('R_1','positive');
    R_2 = sym('R_2','positive');
    L_1 = sym('L_1','positive');
    L_2 = sym('L_2','positive');
    C_1 = sym('C_1','positive');
    C_2 = sym('C_2','positive');
    L_alpha1 = sym('L_alpha1','positive');
    L_alpha2 = sym('L_alpha2','positive');
    omega = sym('omega','positive');
    omega_0 = sym('omega_0','positive');

    syms i_1d i_1q i_2d i_2q v_c1d v_c1q v_c2d v_c2q v_1d v_1q V_dcout

    %% Nonlinear model

    f1 = omega*i_1q + (-R_1*i_1d - (k_nom*sqrt(L_1*L_2))*R_2/L_2*i_2d - v_c1d - (k_nom*sqrt(L_1*L_2))/L_2*v_c2d + ...
    v_1d - (k_nom*sqrt(L_1*L_2))/L_2*i_2d/sqrt(i_2d^(2) + i_2q^(2))*4/pi*V_dcout)/L_alpha1; 

    f2 = -omega*i_1d + (-R_1*i_1q - (k_nom*sqrt(L_1*L_2))*R_2/L_2*i_2q - v_c1q - (k_nom*sqrt(L_1*L_2))/L_2*v_c2q + ...
    v_1q - (k_nom*sqrt(L_1*L_2))/L_2*i_2q/sqrt(i_2d^(2) + i_2q^(2))*4/pi*V_dcout)/L_alpha1; 

    f3 = omega*i_2q + (-(k_nom*sqrt(L_1*L_2))*R_1/L_1*i_1d - R_2*i_2d - (k_nom*sqrt(L_1*L_2))/L_1*v_c1d - v_c2d + ...
    (k_nom*sqrt(L_1*L_2))/L_1*v_1d - i_2d/sqrt(i_2d^(2) + i_2q^(2))*4/pi*V_dcout)/L_alpha2; 

    f4 = -omega*i_2d + (-(k_nom*sqrt(L_1*L_2))*R_1/L_1*i_1q - R_2*i_2q - (k_nom*sqrt(L_1*L_2))/L_1*v_c1q - v_c2q + ...
    (k_nom*sqrt(L_1*L_2))/L_1*v_1q - i_2q/sqrt(i_2d^(2) + i_2q^(2))*4/pi*V_dcout)/L_alpha2;

    f5 = omega*v_c1q + 1/C_1*i_1d;

    f6 = -omega*v_c1d + 1/C_1*i_1q;

    f7 = omega*v_c2q + 1/C_2*i_2d;

    f8 = -omega*v_c2d + 1/C_2*i_2q;

    %% Linearization

    A = jacobian([f1;f2;f3;f4;f5;f6;f7;f8], [i_1d i_1q i_2d i_2q v_c1d v_c1q v_c2d v_c2q]);
    B = jacobian([f1;f2;f3;f4;f5;f6;f7;f8], [v_1d v_1q omega V_dcout]);
    
    % Steady state from Maple
    i_1d0 = (4*(k_nom*sqrt(L_1*L_2))*V_dcout*omega_0 + R_2*V_10*pi)/(pi*(omega_0^2*(k_nom*sqrt(L_1*L_2))^2 + R_2*R_1));
    i_1q0 = 0;
    i_2d0 = 0;
    i_2q0 = (omega_0*(k_nom*sqrt(L_1*L_2))*V_10-R_1*4/pi*V_dcout)/(R_1*R_2 + omega_0^2*(k_nom*sqrt(L_1*L_2))^2);
    v_c1d0 = 0;
    v_c1q0 = -1/(C_1*omega_0)*i_1d0;
    v_c2d0 = 1/(C_2*omega_0)*i_2q0;
    v_c2q0 = 0;
    L_alpha1 = L_1 - (k_nom*sqrt(L_1*L_2))^2/L_2;
    L_alpha2 = L_2 - (k_nom*sqrt(L_1*L_2))^2/L_1;
%     M = k*sqrt(L_1*L_2);
    % Steady-state assignment
    i_1d = i_1d0;
    i_1q = i_1q0;
    i_2d = i_2d0;
    i_2q = i_2q0;
    v_c1d = v_c1d0;
    v_c1q = v_c1q0;
    v_c2d = v_c2d0;
    v_c2q = v_c2q0;
    omega = omega_0;
    
    % Evaluate and simplify
    A = eval(simplify(A));
    A = simplify(A);
    B = eval(simplify(B));
    B = simplify(B);
%end