function [A, B, C, SteadyState] = getStateSpace(omega_off, R1, R2, xu, xc, k, Vdc)    
    %% Symbolic variables and constants
    V_dcout = sym('V_dcout', 'positive');
    M = sym('M','positive');
    R_1 = sym('R_1','positive');
    R_2 = sym('R_2','positive');
    L_1 = sym('L_1','positive');
    L_2 = sym('L_2','positive');
    C_1 = sym('C_1','positive');
    C_2 = sym('C_2','positive');
    L_alpha1 = sym('L_alpha1','positive');
    L_alpha2 = sym('L_alpha2','positive');
    omega = sym('omega','positive');

    syms i_1d i_1q i_2d i_2q v_c1d v_c1q v_c2d v_c2q v_1d v_1q V_dcout

    %% Nonlinear model

    f1 = omega*i_1q + (-R_1*i_1d + M*R_2/L_2*i_2d - v_c1d + M/L_2*v_c2d + ...
    v_1d + M/L_2*i_2d/sqrt(i_2d^(2) + i_2q^(2))*4/pi*V_dcout)/L_alpha1; 

    f2 = -omega*i_1d + (-R_1*i_1q + M*R_2/L_2*i_2q - v_c1q + M/L_2*v_c2q + ...
    v_1q + M/L_2*i_2q/sqrt(i_2d^(2) + i_2q^(2))*4/pi*V_dcout)/L_alpha1; 

    f3 = omega*i_2q + (M*R_1/L_1*i_1d - R_2*i_2d + M/L_1*v_c1d - v_c2d  - ...
    M/L_1*v_1d - i_2d/sqrt(i_2d^(2) + i_2q^(2))*4/pi*V_dcout)/L_alpha2; 

    f4 = -omega*i_2d + (M*R_1/L_1*i_1q - R_2*i_2q + M/L_1*v_c1q - v_c2q - ...
    M/L_1*v_1q - i_2q/sqrt(i_2d^(2) + i_2q^(2))*4/pi*V_dcout)/L_alpha2;

    f5 = omega*v_c1q + 1/C_1*i_1d;

    f6 = -omega*v_c1d + 1/C_1*i_1q;

    f7 = omega*v_c2q + 1/C_2*i_2d;

    f8 = -omega*v_c2d + 1/C_2*i_2q;

    
    %% Linearization

    A = jacobian([f1;f2;f3;f4;f5;f6;f7;f8], [i_1d i_1q i_2d i_2q v_c1d v_c1q v_c2d v_c2q]);
    B = jacobian([f1;f2;f3;f4;f5;f6;f7;f8], [v_1d v_1q omega V_dcout]);
    
    % Steady-state
    SteadyState = getSteadyState(omega_off, R1, R2, xu, xc, k, Vdc);
    
    % Steady-state assignment
    i_1d = SteadyState(1);
    i_1q = SteadyState(2);
    i_2d = SteadyState(3);
    i_2q = SteadyState(4);
    v_c1d = SteadyState(5);
    v_c1q = SteadyState(6);
    v_c2d = SteadyState(7);
    v_c2q = SteadyState(8);
    omega = omega_off;
    
    % Load nominal parameters
    load('parameters.mat');
    
    % Modify appropriate parameters
    M = k*sqrt(L_1*L_2);
    L_alpha1 = L_1 - M^(2)/L_2;
    L_alpha2 = L_2 - M^(2)/L_1; 
    R_1 = R1;
    R_2 = R2;
    C_1 = xc*C_2*L_2/L_1;
    V_10 = sqrt(L_1/L_2)*4/pi*V_dcout/xu;
    V_dcout = Vdc;
    
    % Evaluate symbolic matrices
    A = eval(A);
    B = eval(B);
    C = eye(length(A));

end