%%
%close all
clear all

load('parameters.mat')
Vdc = V_dcout;
xu = sqrt(L_1/L_2)*V_2nom/V_1nom;
xc = 1.00;
omega = omega_0;
k = k_nom;
[Ad, Bd, ~, SteadyState] = getStateSpace(omega_0, R_1, R_2, xu, xc, k_nom, Vdc);
Cd = [sqrt(L_1/L_2)*V_2nom/xu 0 0 0 0 0 0 0; 
    0 0 4/pi*V_dcout*SteadyState(3)/sqrt((SteadyState(3)^2 + SteadyState(4)^2)) ...
        4/pi*V_dcout*SteadyState(4)/sqrt(SteadyState(3)^2 + SteadyState(4)^2) 0 0 0 0];
sy = ss(Ad, Bd, Cd, []);
sys = minreal(sy);
zer = tzero(sys);
poles = eig(sys);
Dd = zeros(1,4);
 

G = tf(sys);
Gfreq = freqresp(G,0);
Gfreq(abs(real(Gfreq)) < 1e-5) = 0; 
Gfreq2 = freqresp(G,9999999999999999999);
Gfreq2(abs(real(Gfreq2)) < 1e-5) = 0; 
Gfreq2(abs(imag(Gfreq2)) < 1e-5) = 0; 
rga = Gfreq.*pinv(Gfreq).';
rga2 = Gfreq2.*pinv(Gfreq2).';
% % RGA
% rgadyn = G.*pinv(G).';
% % rga = minreal(rga);
% % rga0 = freqresp(rga, 0);
% % rgainf = freqresp(rga, 9999999999999999);
%
System = sys; % Define System to reduce
Order = [4 2];
 
% Create option set for balred command
Options = balredOptions();
Options.StateElimMethod = 'MatchDC'; % State elimination method
 
% Compute reduced order approximation
ReducedSystem = balred(System,Order,Options);

% Create option set for balred command
Options2 = balredOptions();
Options2.StateElimMethod = 'truncate'; % State elimination method
 
% Compute reduced order approximation
ReducedSystem2 = balred(System,Order,Options2);

[Ar, Br, Cr, Dr] = ssdata(ReducedSystem2(:,:,2,1));

%% Response
tfsys = tf(sys);
sys1 = tfsys(1,1);
zerozero=zero(sys1);
[num, den] = tfdata(sys1, 'v');
%sys1 = tf(num, den)
[hb, gg] = balreal(sys1);
hmdc = modred(hb,3:8,'MatchDC');
hmdc2 = modred(hb,5:8,'MatchDC');
hdel = modred(hb,3:8,'Truncate');
hdel2 = modred(hb,5:8,'Truncate');
%hdeltf = tf(hdel);

figure
bode(sys1, '-b', hmdc, '--r')
legend('Original system', '2nd order approximation (MatchDC)', 'Interpreter', 'latex', 'FontSize', 12)

figure
bode(sys1, '-b', hmdc2, '--r')
legend('Original system', '4th order approximation (MatchDC)', 'Interpreter', 'latex', 'FontSize', 12)

figure
step(sys1, '-b', hmdc, '--r')
legend('Original system', '2nd order approximation (MatchDC)', 'Interpreter', 'latex', 'FontSize', 12)

figure
step(sys1, '-b', hmdc2, '--r')
legend('Original system', '4th order approximation (MatchDC)', 'Interpreter', 'latex', 'FontSize', 12)



% % Create comparison plot
% figure
% bode(System(1:4,1:4), 'b',ReducedSystem(1:4,1:4,1,1),'--r');
% title("fourth order 1-4")
% figure
% bode(System(5:8,1:4), 'b',ReducedSystem(5:8,1:4,1,1),'--r');
% title("fourth order 5-8")
% figure
% bode(System(1:4,1:4), 'b',ReducedSystem(1:4,1:4,2,1),'--r');
% title("secondh order 1-4")
% figure
% bode(System(5:8,1:4), 'b',ReducedSystem(5:8,1:4,2,1),'--r');
% title("secondh order 5-8")

%%
figure
sigmaplot(System, 'b', ReducedSystem(:,:,1,1), '--r')
legend('Original system', '4th order approximation (MatchDC)', 'FontSize', 12)

figure
sigmaplot(System, 'b', ReducedSystem(:,:,2,1), '--r')
legend('Original system', '2nd order approximation (MatchDC)', 'FontSize', 12)

figure
sigmaplot(System, 'b', ReducedSystem2(:,:,1,1), '--r')
legend('Original system', '4th order approximation (Truncate)', 'FontSize', 12)

figure
sigmaplot(System, 'b', ReducedSystem2(:,:,2,1), '--r')
legend('Original system', '2nd order approximation (Truncate)', 'FontSize', 12)

%%
figure
grid on
step(System(1,1,1,1), 'b', ReducedSystem2(1,1,1,1),'--r', ReducedSystem2(1,1,2,1),'--g');
legend('Original system', '4th order approximation (Truncate)', '2nd order approximation (Truncate)','FontSize', 12)

%%
figure
grid on
step(System(1,3,1,1), 'b', ReducedSystem2(1,3,1,1),'--r', ReducedSystem2(1,3,2,1),'--g');
legend('Original system', '4th order approximation (Truncate)', '2nd order approximation (Truncate)','FontSize', 12)
%ylim([-1 1])