% Get symbolic A-matrix with correct steady-state-values
[A, ~] = getSSFromMaple_expanded();

% Create symbolic variables and constants
V_10 = sym('V_10', 'positive');
V_dcout = sym('V_dcout', 'positive');
k_nom = sym('k_nom','positive');
R_1 = sym('R_1','positive');
R_2 = sym('R_2','positive');
L_1 = sym('L_1','positive');
L_2 = sym('L_2','positive');
C_1 = sym('C_1','positive');
C_2 = sym('C_2','positive');
omega_0 = sym('omega_0','positive');

% Changeable parameters
param = [R_1 R_2 L_1 L_2 C_1 C_2 k_nom V_10 V_dcout omega_0];

% Initialize cells and get modal decomposition
symMatrixCell = cell(1, length(param));
numMatrixCell = cell(1, length(param));
paramSensMatrix = zeros(length(A), length(param));
[l, r, eigen] = getEigen();

% Obtain cell containing all 10 symbolic matrices
for i=1:length(param)
    symMatrixCell{i} = diff(A, param(i));
end

load('parameters.mat')

% Obtain cell containing all 10 numeric matrices
for i=1:length(param)
    numMatrixCell{i} = eval(symMatrixCell{i});
end

% Obtain parametric sensitivity matrix
for i=1:length(param)
    for j = 1:length(A)
        paramSensMatrix(j, i) = r(:,j)'*numMatrixCell{i}*l(:,j)/(r(:,j)'*l(:,j));
    end
end

hold on
scatter(real(diag(eigen)), imag(diag(eigen)));