% Cleanup
clear all
close all

% Load nominal parameters
load('parameters.mat')
Vdc = V_dcout;

% Apply appropriaate detuning and unbalance
xu = 0.95; %sqrt(L_1/L_2)*V_2nom/V_1nom;
xc = 0.97;

% Get nominal values
Pnom = getPower(k_nom, V_2nom, R_1, R_2, C_2, L_1, L_2, xu, xc, omega_0);
Pref = Pnom;
Inom = Pnom/V_1nom;

% Choose iterations and range
N = 300;
inc = 2*k_nom/N;
k = k_nom;

% Initialize vectors and tables
eigTable = zeros(8,N);
eigTableGramian = zeros(8,N);
couplingVec = zeros(1,N);
omegaVec = zeros(1,N);
ssVec = zeros(8,N);
powerVec = zeros(1,N);
currentVec = zeros(1,N);
argZVec = zeros(1,N);
traceVec = zeros(1,N);
volVec = zeros(1,N);
minEigVec = zeros(1,N);

for i = 1:N
    omega = getOmega_constP_supres(k, V_2nom, R_1, R_2, C_2, L_1, L_2, xu, xc, Pref, omega_0); % Get omega for keeping constant power
    omegaVec(i) = omega; % Assign omega
    powerVec(i) = getPower(k, V_2nom, R_1, R_2, C_2, L_1, L_2, xu, xc, omega); % Get corresponding power
    [A, B, C, SteadyState] = getStateSpace(omega, R_1, R_2, xu, xc, k, Vdc); % Linearize model at given coupling and omega
    eigTable(:, i) = eig(A); % Calculate eigenvalue
    currentVec(i) = sqrt(SteadyState(1)^2 + SteadyState(2)^2); % Calculate amplitude of current at sending side
    argZVec(i) = angle(V_1nom/(SteadyState(1)+1i*SteadyState(2))); % Calculate argument of impedencec seen by source
    C = diag([1 1 1 1 0 0 0 0]);
    sys = ss(A, B, C, 0); % Create state-space
    Wc = gram(sys,'o');
    Eigenvalues = eig(Wc);
    eigTableGramian(:, i) = Eigenvalues;
    traceVec(i) = trace(Wc);
    detWc = det(Wc);
    gam = gamma(length(A)/2 + 1);
    volVec(i) = pi^(length(A)/2)*(sqrt(detWc))^(1/length(A))/gam;
    minEigVec(i) = min(Eigenvalues);
    ssVec(:,i) = SteadyState';
    couplingVec(i) = k;
    k = k + inc;
end
kmax = k;
Mmax = kmax*sqrt(L_1*L_2);

% Transespose tables of eigenvalues
trans = eigTable';
realEig = real(trans);
imagEig = imag(trans);

transGramian = eigTableGramian';
realEigGramian = real(transGramian);
imagEigGramian = imag(transGramian);

%% Plotting 

% Plot eigenvalue trajectories of A-matrix
figure()
hold on
grid on
for i = 1:8
    scatter(realEig(:,i), imagEig(:,i), 1, 'b');
end
xlabel('Real part')
ylabel('Imaginary part')
scatter(realEig(1,:), imagEig(1,:), 'o', 'b');
scatter(realEig(N,:), imagEig(N,:), 'v', 'r');

% Plot eigenvalue trajectories of Gramian
figure()
subplot(2,1,1)
hold on
grid on
for i = 1:4
    scatter(realEigGramian(:,i), imagEigGramian(:,i), 1, 'b');
end
xlabel('Real part')
ylabel('Imaginary part')
scatter(realEigGramian(1,1:4), imagEigGramian(1,1:4), 'o', 'b');
scatter(realEigGramian(N,1:4), imagEigGramian(N,1:4), 'v', 'r');

subplot(2,1,2)
hold on
grid on
for i = 5:8
    scatter(realEigGramian(:,i), imagEigGramian(:,i), 1, 'b');
end
xlabel('Real part')
ylabel('Imaginary part')
scatter(realEigGramian(1,5:8), imagEigGramian(1,5:8), 'o', 'b');
scatter(realEigGramian(N,5:8), imagEigGramian(N,5:8), 'v', 'r');

% Plot trace of Gramian
figure()
plot(omegaVec/omega_0, traceVec, 'LineWidth', 1.3);
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Trace $tr(W_c)$', 'interpreter', 'latex', 'Fontsize', 14)
legend('$tr(W_c(\omega, k))$', 'interpreter', 'latex', 'Fontsize', 16)
xlim([1.024 1.54])
grid on

% Plot volume of ellipsoid
figure
plot(omegaVec/omega_0, volVec, 'LineWidth', 1.3);
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Volume of ellipsoid $Vol(\mathcal{E}_{min})$', 'interpreter', 'latex', 'Fontsize', 14)
legend('$Vol(\mathcal{E}_{min}(\omega, k))$', 'interpreter', 'latex', 'Fontsize', 16)
xlim([1.024 1.54])
grid on

% Plot minimum eigenvalue of Gramian
figure()
plot(omegaVec/omega_0, minEigVec, 'LineWidth', 1.3);
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Min. eigenvalue $\lambda_{min}(W_c)$', 'interpreter', 'latex', 'Fontsize', 14)
legend('$\lambda_{min}(W_c(\omega, k))$', 'interpreter', 'latex', 'Fontsize', 16)
xlim([1.024 1.54])
grid on

% Plot frequency trajectory
figure
plot(couplingVec/k_nom, real(omegaVec)/omega_0, 'LineWidth', 1.3);
xlabel('Normalized coupling $(k/k_{nom})$', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
legend('$\omega(k)$', 'interpreter', 'latex', 'Fontsize', 16)
xlim([1.02 1.54])
grid on

% Plot power trajectory
figure
plot(couplingVec/k_nom, abs(powerVec)/Pnom, 'k', 'LineWidth', 1.3);
xlabel('Normalized coupling $(k/k_{nom})$', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized power $(P_{out}/P_0)$', 'interpreter', 'latex', 'Fontsize', 14)
ylim([Pref/Pnom - 0.01 Pref/Pnom + 0.01])
xlim([1.024 1.54])
legend('$P(\omega, k)$', 'interpreter', 'latex', 'Fontsize', 16)
grid on

% Plot angle of impedance seen by source
figure
plot(omegaVec/omega_0, argZVec*180/(2*pi), 'LineWidth', 1.3);
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('$\angle Z_{send}$ [deg]', 'interpreter', 'latex', 'Fontsize', 14)
legend('$\angle Z_{send}(\omega, k)$', 'interpreter', 'latex', 'Fontsize', 16)
ylim([-5 -3])
xlim([1.02 1.54])
grid on

% Plot sending side current
figure
plot(omegaVec/omega_0, currentVec/Inom, 'LineWidth', 1.3);
xlabel('Normalized frequency ($\omega/\omega_0$)', 'interpreter', 'latex', 'Fontsize', 14)
ylabel('Normalized current $(I_1/I_{1,0})$', 'interpreter', 'latex', 'Fontsize', 14)
legend('$I_1(\omega, k)$', 'interpreter', 'latex', 'Fontsize', 16)
ylim([0.77 0.78])
xlim([1.02 1.54])
grid on