function [i_1d0, i_1q0, i_2d0, i_2q0, v_c1d0, v_c1q0, v_c2d0, v_c2q0] = getSteadyStateSol()
    pi =sym('pi');
    M = sym('M','positive');
    R_1 = sym('R_1','positive');
    R_2 = sym('R_1','positive');
    L_1 = sym('L_1','positive');
    L_2 = sym('L_2','positive');
    C_1 = sym('C_1','positive');
    C_2 = sym('C_2','positive');
    L_alpha1 = sym('L_alpha1','positive');
    L_alpha2 = sym('L_alpha2','positive');
    omega = sym('omega','positive');
    omega_0 = sym('omega_0','positive');
    syms i_1d i_1q i_2d i_2q v_c1d v_c1q v_c2d v_c2q v_1d v_1q V_dcout 

    %% Main model

    f1 = omega*i_1q + (-R_1*i_1d + M*R_2/L_2*i_2d - v_c1d + M/L_2*v_c2d + ...
    v_1d + M/L_2*i_2d*4/pi*V_dcout/sqrt(i_2d^(2) + i_2q^(2)))/L_alpha1 == 0; 

    f2 = -omega*i_1d + (-R_1*i_1q + M*R_2/L_2*i_2q - v_c1q + M/L_2*v_c2q + ...
    v_1q + M/L_2*i_2q*4/pi*V_dcout/sqrt(i_2d^(2) + i_2q^(2)))/L_alpha1 == 0; 

    f3 = omega*i_2q + (M*R_1/L_1*i_1d - R_2*i_2d + M/L_1*v_c1d - v_c2d  - ...
    M/L_1*v_1d - i_2d*4/pi*V_dcout/sqrt(i_2d^(2) + i_2q^(2)))/L_alpha2 == 0; 

    f4 = -omega*i_2d + (M*R_1/L_1*i_1q - R_2*i_2q + M/L_1*v_c1q - v_c2q - ...
    M/L_1*v_1q - i_2q*4/pi*V_dcout/sqrt(i_2d^(2) + i_2q^(2)))/L_alpha2 == 0;

    f5 = omega*v_c1q + 1/C_1*i_1d == 0;

    f6 = -omega*v_c1d + 1/C_1*i_1q == 0;

    f7 = omega*v_c2q + 1/C_2*i_2d == 0;

    f8 = -omega*v_c2d + 1/C_2*i_2q == 0;

    % Solve voltages in terms of currents
    eqns = [f5, f6, f7, f8];
    vars = [v_c1d, v_c1q, v_c2d, v_c2q];
    solVoltage = solve(eqns, vars);

    v_c1d0 = solVoltage.v_c1d;
    v_c1q0 = solVoltage.v_c1q;
    v_c2d0 = solVoltage.v_c2d;
    v_c2q0 = solVoltage.v_c2q;

    % Substitution of steady-state voltages
    f1 = subs(f1, v_c1d, v_c1d0);
    f1 = subs(f1, v_c2d, v_c2d0);

    f2 = subs(f2, v_c1q, v_c1q0);
    f2 = subs(f2, v_c2q, v_c2q0);

    f3 = subs(f3, v_c1d, v_c1d0);
    f3 = subs(f3, v_c2d, v_c2d0);

    f4 = subs(f4, v_c1q, v_c1q0);
    f4 = subs(f4, v_c2q, v_c2q0);

    % Substitution of R_eq
    syms R_eq
    f1 = subs(f1, 4/pi*V_dcout/sqrt(i_2d^(2) + i_2q^(2)), R_eq);
    f2 = subs(f2, 4/pi*V_dcout/sqrt(i_2d^(2) + i_2q^(2)), R_eq);
    f3 = subs(f3, 4/pi*V_dcout/sqrt(i_2d^(2) + i_2q^(2)), R_eq);
    f4 = subs(f4, 4/pi*V_dcout/sqrt(i_2d^(2) + i_2q^(2)), R_eq);

    % Assumptions
    V_10 = sym('V_10','positive');
    v_1d = V_10;
    v_1q = 0;

    % Single resonant frequency
    omega = 1/sqrt(L_1*C_1);
    C_1 = C_2*L_2/L_1;

    % Leakage factors
    L_alpha1 = L_1 - M^2/L_2;
    L_alpha2 = L_2 - M^2/L_1;

    % Solution of steady-state currents
    eqns2 = [f1, f2, f3, f4];
    vars2 = [i_1d, i_1q, i_2d, i_2q];
    solCurrent = solve(eqns2, vars2);

    i_1d0 = solCurrent.i_1d;
    i_1q0 = solCurrent.i_2d;
    i_2d0 = solCurrent.i_1q;
    i_2q0 = solCurrent.i_2q;

    % Simplify
    i_1d0 = eval(simplify(i_1d0));
    i_1q0 = eval(simplify(i_1q0));
    i_2d0 = eval(simplify(i_2d0));
    i_2q0 = eval(simplify(i_2q0));

    % Assume negligible losses
    R_1 = 0;
    R_2 = 0;

    % Simplify further
    i_1d0 = eval(simplify(i_1d0));
    i_1q0 = eval(simplify(i_1q0));
    i_2d0 = eval(simplify(i_2d0));
    i_2q0 = eval(simplify(i_2q0));
    
    % i_1q0 and i_2d0 is zero and not treated further
    
    % Substitution of resonant frequency
    i_1d0 = subs(i_1d0, C_2*L_2, 1/omega_0^2);
    i_2q0 = subs(i_2q0, C_2*L_2, 1/omega_0^2);

    % Substitution of R_eq
    syms I_2
    R_eq = 4/pi*V_dcout/I_2;

    % Simplify
    i_1d0 = eval(simplify(i_1d0));

    % Substitution of I_2
    I_2 = V_10/(omega_0*M);

    % Final simplification;
    i_1d0 = eval(simplify(i_1d0));
    i_2q0 = eval(simplify(i_2q0));
    
    % Substitute steady-state resonant frequency
    syms omega % Force omega to be variable
    v_c1d0 = subs(v_c1d0, omega, omega_0);
    v_c1q0 = subs(v_c1q0, omega, omega_0);
    v_c2d0 = subs(v_c2d0, omega, omega_0);
    v_c2q0 = subs(v_c2q0, omega, omega_0);
   
    % Substitution of steady-state currents
    v_c1d0 = subs(v_c1d0, i_1q, i_1q0);
    v_c1q0 = subs(v_c1q0, i_1d, i_1d0);
    v_c2d0 = subs(v_c2d0, i_2q, i_2q0);
    v_c2q0 = subs(v_c2q0, i_2d, i_2d0);
    
end
